@@ -14,7 +14,6 @@ import warnings
 
 from click import echo as click_echo
 from first import first
-
 try:
     from weakref import finalize
 except ImportError:
@@ -36,13 +35,7 @@ try:
     from urllib.parse import urlparse
 except ImportError:
     from urlparse import urlparse
-try:
-    from pathlib import Path
-except ImportError:
-    try:
-        from .vendor.pathlib2 import Path
-    except ImportError:
-        pass
+
 from distutils.spawn import find_executable
 from contextlib import contextmanager
 from .pep508checker import lookup
@@ -56,7 +49,6 @@ try:
     from collections.abc import Mapping
 except ImportError:
     from collections import Mapping
-from .vendor.requirementslib import Requirement
 
 if six.PY2:
 
@@ -180,12 +172,18 @@ class HackedPythonVersion(object):
         self.python_path = python_path
 
     def __enter__(self):
-        os.environ['PIP_PYTHON_VERSION'] = str(self.python_version)
-        os.environ['PIP_PYTHON_PATH'] = str(self.python_path)
+        # Only inject when the value is valid
+        if self.python_version:
+            os.environ['PIP_PYTHON_VERSION'] = str(self.python_version)
+        if self.python_path:
+            os.environ['PIP_PYTHON_PATH'] = str(self.python_path)
 
     def __exit__(self, *args):
         # Restore original Python version information.
-        del os.environ['PIP_PYTHON_VERSION']
+        try:
+            del os.environ['PIP_PYTHON_VERSION']
+        except KeyError:
+            pass
 
 
 def prepare_pip_source_args(sources, pip_args=None):
@@ -231,6 +229,7 @@ def actually_resolve_deps(
     from pipenv.patched.piptools.scripts.compile import get_pip_command
     from pipenv.patched.piptools import logging as piptools_logging
     from pipenv.patched.piptools.exceptions import NoCandidateFound
+    from .vendor.requirementslib import Requirement
     from ._compat import TemporaryDirectory, NamedTemporaryFile
 
     class PipCommand(basecommand.Command):
@@ -609,6 +608,7 @@ def is_installable_file(path):
     from .patched.notpip._internal.utils.misc import is_installable_dir
     from .patched.notpip._internal.utils.packaging import specifiers
     from .patched.notpip._internal.download import is_archive_file
+    from ._compat import Path
 
     if hasattr(path, 'keys') and any(
         key for key in path.keys() if key in ['file', 'path']
@@ -853,6 +853,7 @@ def find_windows_executable(bin_path, exe_name):
 
 
 def path_to_url(path):
+    from ._compat import Path
     return Path(normalize_drive(os.path.abspath(path))).as_uri()
 
 
@@ -921,9 +922,11 @@ def is_valid_url(url):
 def is_pypi_url(url):
     return bool(re.match(r'^http[s]?:\/\/pypi(?:\.python)?\.org\/simple[\/]?$', url))
 
+
 def replace_pypi_sources(sources, pypi_replacement_source):
     return [pypi_replacement_source] + [source for source in sources if not is_pypi_url(source['url'])]
 
+
 def create_mirror_source(url):
     return {'url': url, 'verify_ssl': url.startswith('https://'), 'name': urlparse(url).hostname}
 
@@ -1158,7 +1161,8 @@ def get_vcs_deps(
     pypi_mirror=None,
 ):
     from .patched.notpip._internal.vcs import VcsSupport
-    from ._compat import TemporaryDirectory
+    from ._compat import TemporaryDirectory, Path
+    from .vendor.requirementslib import Requirement
 
     section = "vcs_dev_packages" if dev else "vcs_packages"
     reqs = []
@@ -1275,3 +1279,18 @@ def fs_str(string):
 
 
 _fs_encoding = sys.getfilesystemencoding() or sys.getdefaultencoding()
+
+
+# Duplicated from Pew to avoid importing it (performance considerations).
+def get_workon_home():
+    from ._compat import Path
+    workon_home = os.environ.get('WORKON_HOME')
+    if not workon_home:
+        if os.name == 'nt':
+            workon_home = '~/.virtualenvs'
+        else:
+            workon_home = os.path.join(
+                os.environ.get('XDG_DATA_HOME', '~/.local/share'),
+                'virtualenvs',
+            )
+    return Path(os.path.expandvars(workon_home)).expanduser()
